#!/usr/bin/env bash
set -eu

if [ ! -v SCRIPTS_DIR ]; then
  SCRIPTS_DIR=$(cd $(dirname $0);pwd)
fi

if [ ! -v WORK_DIR ]; then
  WORK_DIR=$SCRIPTS_DIR/workdir
fi

SSP3_FILE=ssp3_arm_gcc-20190902.tar.gz
SSP3_DOWNLOAD_URL="https://www.toppers.jp/MEMBERS/early/third/$SSP3_FILE"
SSP3_DIR=$WORK_DIR/ssp3
SSP3_BUILD_DIR=$SSP3_DIR/build

: "confirm username and password" && {
  read -p    "username for http://www.toppers.jp/MEMBERS): " user
  read -s -p "password: " pass
  echo
}

: "install build tools" && {
  if [ -e $SCRIPTS_DIR/setup_tools.sh ]; then
    bash $SCRIPTS_DIR/setup_tools.sh
  else
    echo "script file \"setup_tools.sh\" is not found in \"$SCRIPTS_DIR\". abort."
    exit 1
  fi
}

: "download ssp3 kernel file" && {
  mkdir -p $WORK_DIR
  cd $WORK_DIR
  wget $SSP3_DOWNLOAD_URL --http-user=$user --http-password=$pass
}

: "setup files" && {
  mkdir -p $SSP3_DIR
  tar xvf $SSP3_FILE -C $SSP3_DIR --strip-components=2
  cd $SSP3_DIR
  sed -i -e 's/\#COPTS/COPTS/g' target/ct11mpcore_gcc/Makefile.target
}

: "build kernel" && {
  mkdir -p $SSP3_BUILD_DIR
  cd $SSP3_BUILD_DIR
  $SSP3_DIR/configure.rb -T ct11mpcore_gcc
  make
}
